Stan Math Library: stan/math/prim/scal/fun.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

fun.hpp File Reference
`#include <stan/math/prim/scal/fun/abs.hpp>`
`#include <stan/math/prim/scal/fun/as_bool.hpp>`
`#include <stan/math/prim/scal/fun/bessel_first_kind.hpp>`
`#include <stan/math/prim/scal/fun/bessel_second_kind.hpp>`
`#include <stan/math/prim/scal/fun/binary_log_loss.hpp>`
`#include <stan/math/prim/scal/fun/binomial_coefficient_log.hpp>`
`#include <stan/math/prim/scal/fun/constants.hpp>`
`#include <stan/math/prim/scal/fun/corr_constrain.hpp>`
`#include <stan/math/prim/scal/fun/corr_free.hpp>`
`#include <stan/math/prim/scal/fun/digamma.hpp>`
`#include <stan/math/prim/scal/fun/divide.hpp>`
`#include <stan/math/prim/scal/fun/exp2.hpp>`
`#include <stan/math/prim/scal/fun/F32.hpp>`
`#include <stan/math/prim/scal/fun/falling_factorial.hpp>`
`#include <stan/math/prim/scal/fun/fdim.hpp>`
`#include <stan/math/prim/scal/fun/gamma_p.hpp>`
`#include <stan/math/prim/scal/fun/gamma_q.hpp>`
`#include <stan/math/prim/scal/fun/grad_2F1.hpp>`
`#include <stan/math/prim/scal/fun/grad_F32.hpp>`
`#include <stan/math/prim/scal/fun/grad_inc_beta.hpp>`
`#include <stan/math/prim/scal/fun/grad_reg_inc_beta.hpp>`
`#include <stan/math/prim/scal/fun/grad_reg_inc_gamma.hpp>`
`#include <stan/math/prim/scal/fun/ibeta.hpp>`
`#include <stan/math/prim/scal/fun/identity_constrain.hpp>`
`#include <stan/math/prim/scal/fun/identity_free.hpp>`
`#include <stan/math/prim/scal/fun/if_else.hpp>`
`#include <stan/math/prim/scal/fun/inc_beta.hpp>`
`#include <stan/math/prim/scal/fun/inc_beta_dda.hpp>`
`#include <stan/math/prim/scal/fun/inc_beta_ddb.hpp>`
`#include <stan/math/prim/scal/fun/inc_beta_ddz.hpp>`
`#include <stan/math/prim/scal/fun/int_step.hpp>`
`#include <stan/math/prim/scal/fun/inv.hpp>`
`#include <stan/math/prim/scal/fun/inv_cloglog.hpp>`
`#include <stan/math/prim/scal/fun/inv_logit.hpp>`
`#include <stan/math/prim/scal/fun/inv_sqrt.hpp>`
`#include <stan/math/prim/scal/fun/inv_square.hpp>`
`#include <stan/math/prim/scal/fun/inverse_softmax.hpp>`
`#include <stan/math/prim/scal/fun/is_inf.hpp>`
`#include <stan/math/prim/scal/fun/is_nan.hpp>`
`#include <stan/math/prim/scal/fun/is_uninitialized.hpp>`
`#include <stan/math/prim/scal/fun/lb_constrain.hpp>`
`#include <stan/math/prim/scal/fun/lb_free.hpp>`
`#include <stan/math/prim/scal/fun/lbeta.hpp>`
`#include <stan/math/prim/scal/fun/lgamma.hpp>`
`#include <stan/math/prim/scal/fun/lmgamma.hpp>`
`#include <stan/math/prim/scal/fun/log1m.hpp>`
`#include <stan/math/prim/scal/fun/log1m_exp.hpp>`
`#include <stan/math/prim/scal/fun/log1m_inv_logit.hpp>`
`#include <stan/math/prim/scal/fun/log1p.hpp>`
`#include <stan/math/prim/scal/fun/log1p_exp.hpp>`
`#include <stan/math/prim/scal/fun/log2.hpp>`
`#include <stan/math/prim/scal/fun/log_diff_exp.hpp>`
`#include <stan/math/prim/scal/fun/log_falling_factorial.hpp>`
`#include <stan/math/prim/scal/fun/log_inv_logit.hpp>`
`#include <stan/math/prim/scal/fun/log_mix.hpp>`
`#include <stan/math/prim/scal/fun/log_rising_factorial.hpp>`
`#include <stan/math/prim/scal/fun/log_sum_exp.hpp>`
`#include <stan/math/prim/scal/fun/logical_and.hpp>`
`#include <stan/math/prim/scal/fun/logical_eq.hpp>`
`#include <stan/math/prim/scal/fun/logical_gt.hpp>`
`#include <stan/math/prim/scal/fun/logical_gte.hpp>`
`#include <stan/math/prim/scal/fun/logical_lt.hpp>`
`#include <stan/math/prim/scal/fun/logical_lte.hpp>`
`#include <stan/math/prim/scal/fun/logical_negation.hpp>`
`#include <stan/math/prim/scal/fun/logical_neq.hpp>`
`#include <stan/math/prim/scal/fun/logical_or.hpp>`
`#include <stan/math/prim/scal/fun/logit.hpp>`
`#include <stan/math/prim/scal/fun/lub_constrain.hpp>`
`#include <stan/math/prim/scal/fun/lub_free.hpp>`
`#include <stan/math/prim/scal/fun/modified_bessel_first_kind.hpp>`
`#include <stan/math/prim/scal/fun/modified_bessel_second_kind.hpp>`
`#include <stan/math/prim/scal/fun/modulus.hpp>`
`#include <stan/math/prim/scal/fun/multiply_log.hpp>`
`#include <stan/math/prim/scal/fun/owens_t.hpp>`
`#include <stan/math/prim/scal/fun/Phi.hpp>`
`#include <stan/math/prim/scal/fun/Phi_approx.hpp>`
`#include <stan/math/prim/scal/fun/positive_constrain.hpp>`
`#include <stan/math/prim/scal/fun/positive_free.hpp>`
`#include <stan/math/prim/scal/fun/primitive_value.hpp>`
`#include <stan/math/prim/scal/fun/prob_constrain.hpp>`
`#include <stan/math/prim/scal/fun/prob_free.hpp>`
`#include <stan/math/prim/scal/fun/promote_scalar.hpp>`
`#include <stan/math/prim/scal/fun/promote_scalar_type.hpp>`
`#include <stan/math/prim/scal/fun/rising_factorial.hpp>`
`#include <stan/math/prim/scal/fun/sign.hpp>`
`#include <stan/math/prim/scal/fun/square.hpp>`
`#include <stan/math/prim/scal/fun/step.hpp>`
`#include <stan/math/prim/scal/fun/trigamma.hpp>`
`#include <stan/math/prim/scal/fun/ub_constrain.hpp>`
`#include <stan/math/prim/scal/fun/ub_free.hpp>`
`#include <stan/math/prim/scal/fun/value_of.hpp>`
`#include <stan/math/prim/scal/fun/value_of_rec.hpp>`

Go to the source code of this file.

[ Stan Home Page ] © 2011–2016, Stan Development Team.